@@ -110,8 +110,12 @@ class FuncTest(testtools.TestCase):
 
     def testFuncTrueFalseEvaluation(self):
         """Should return True if the validating function returns True."""
-        equals_one = lambda x: x == 1
-        always_none = lambda x: None
+
+        def equals_one(x):
+            return x == 1
+
+        def always_none(x):
+            return None
 
         self.assertTrue(mox.Func(equals_one) == 1)
         self.assertFalse(mox.Func(equals_one) == 0)
@@ -210,8 +214,8 @@ class ContainsAttributeValueTest(testtools.TestCase):
 
     def testValidPair(self):
         """Return True if the object has the key attribute that matches."""
-        self.assertTrue(mox.ContainsAttributeValue("key", 1)
-                        == self.test_object)
+        self.assertTrue(mox.ContainsAttributeValue("key", 1) ==
+                        self.test_object)
 
     def testInvalidValue(self):
         """Should return False if the value is not correct."""
@@ -316,8 +320,8 @@ class RegexTest(testtools.TestCase):
 
     def testReprWithFlags(self):
         """repr should return the regular expression pattern and flags."""
-        self.assertTrue(repr(mox.Regex(r"a\s+b", flags=4)) ==
-                        "<regular expression 'a\s+b', flags=4>")
+        self.assertTrue(repr(mox.Regex(r"a\s+b")) ==
+                        "<regular expression 'a\s+b'>")
 
 
 class IsTest(testtools.TestCase):
@@ -764,7 +768,7 @@ class MockAnythingTest(testtools.TestCase):
 
     def testIsReprable(self):
         """Test that MockAnythings can be repr'd without causing a failure."""
-        self.assertTrue('MockAnything' in repr(self.mock_object))
+        self.assertIn('MockAnything', repr(self.mock_object))
 
 
 class MethodCheckerTest(testtools.TestCase):
@@ -961,27 +965,27 @@ class MockObjectTest(testtools.TestCase):
 
     def testFindValidMethods(self):
         """Mock should be able to mock all public methods."""
-        self.assertTrue('ValidCall' in self.mock_object._known_methods)
-        self.assertTrue('OtherValidCall' in self.mock_object._known_methods)
-        self.assertTrue('MyClassMethod' in self.mock_object._known_methods)
-        self.assertTrue('MyStaticMethod' in self.mock_object._known_methods)
-        self.assertTrue('_ProtectedCall' in self.mock_object._known_methods)
-        self.assertTrue('__PrivateCall' not in self.mock_object._known_methods)
-        self.assertTrue(
-            '_TestClass__PrivateCall' in self.mock_object._known_methods)
+        self.assertIn('ValidCall', self.mock_object._known_methods)
+        self.assertIn('OtherValidCall', self.mock_object._known_methods)
+        self.assertIn('MyClassMethod', self.mock_object._known_methods)
+        self.assertIn('MyStaticMethod', self.mock_object._known_methods)
+        self.assertIn('_ProtectedCall', self.mock_object._known_methods)
+        self.assertNotIn('__PrivateCall', self.mock_object._known_methods)
+        self.assertIn(
+            '_TestClass__PrivateCall', self.mock_object._known_methods)
 
     def testFindsSuperclassMethods(self):
         """Mock should be able to mock superclasses methods."""
         self.mock_object = mox.MockObject(ChildClass)
-        self.assertTrue('ValidCall' in self.mock_object._known_methods)
-        self.assertTrue('OtherValidCall' in self.mock_object._known_methods)
-        self.assertTrue('MyClassMethod' in self.mock_object._known_methods)
-        self.assertTrue('ChildValidCall' in self.mock_object._known_methods)
+        self.assertIn('ValidCall', self.mock_object._known_methods)
+        self.assertIn('OtherValidCall', self.mock_object._known_methods)
+        self.assertIn('MyClassMethod', self.mock_object._known_methods)
+        self.assertIn('ChildValidCall', self.mock_object._known_methods)
 
     def testAccessClassVariables(self):
         """Class variables should be accessible through the mock."""
-        self.assertTrue('SOME_CLASS_VAR' in self.mock_object._known_vars)
-        self.assertTrue('_PROTECTED_CLASS_VAR' in self.mock_object._known_vars)
+        self.assertIn('SOME_CLASS_VAR', self.mock_object._known_vars)
+        self.assertIn('_PROTECTED_CLASS_VAR', self.mock_object._known_vars)
         self.assertEqual('test_value', self.mock_object.SOME_CLASS_VAR)
 
     def testEquals(self):
@@ -1183,7 +1187,7 @@ class MockObjectTest(testtools.TestCase):
 
         dummy._Replay()
 
-        self.assertTrue('X' in dummy)
+        self.assertIn('X', dummy)
 
         dummy._Verify()
 
@@ -1257,8 +1261,8 @@ class MockObjectTest(testtools.TestCase):
         # NOT doing dummy[index]
 
         dummy._Replay()
-        function = lambda: [x for x in dummy]
-        self.assertRaises(mox.UnexpectedMethodCallError, function)
+        self.assertRaises(mox.UnexpectedMethodCallError,
+                          lambda: [x for x in dummy])
 
     def testMockGetIter_WithSubClassOfNewStyleClass(self):
         class NewStyleTestClass(object):
